@@ -127,7 +127,7 @@ public:
 
       label=Lum::Label::Create(true,false);
       label->AddLabel(L"Formula:",formula->GetFormula());
-      label->AddLabel(L"Variable name:",formula->GetVariables()[i]->GetName());
+      label->AddLabel(L"Variable:",formula->GetVariables()[i]->GetName());
       label->AddLabel(L"Description:",formula->GetVariables()[i]->GetDescription());
 
       string=new Lum::String();
