@@ -21,6 +21,10 @@
 
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/OneOfMany.h>
+
+#include <Lum/OS/Behaviour.h>
+
 #include <Lum/Combo.h>
 #include <Lum/Label.h>
 #include <Lum/String.h>
@@ -46,30 +50,31 @@ UnitConversion::UnitConversion()
 
 void UnitConversion::CalcSize()
 {
-  Lum::Combo               *combo;
+  Lum::Def::OneOfMany         typeDef(Lum::Def::Desc(L"Type"),
+                                      type,types);
+  Lum::Def::OneOfMany         srcDef(Lum::Def::Desc(L"Source unit"),
+                                     src,srcUnits);
+  Lum::Def::OneOfMany         destDef(Lum::Def::Desc(L"Destination unit"),
+                                      dest,destUnits);
+
+  Lum::Object              *oneOfMany;
   Lum::Label               *label;
   Lum::String              *string;
   Lum::TextValue           *textValue;
 
   label=new Lum::Label();
 
-  combo=new Lum::IndexCombo();
-  combo->SetFlex(true,false);
-  combo->SetModel(type);
-  combo->SetTableModel(types);
-  label->AddLabel(L"Type:",combo);
+  oneOfMany=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(typeDef);
+  oneOfMany->SetFlex(true,false);
+  label->AddLabel(L"Type:",oneOfMany);
 
-  combo=new Lum::IndexCombo();
-  combo->SetFlex(true,false);
-  combo->SetModel(src);
-  combo->SetTableModel(srcUnits);
-  label->AddLabel(L"Source Unit:",combo);
+  oneOfMany=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(srcDef);
+  oneOfMany->SetFlex(true,false);
+  label->AddLabel(L"Source Unit:",oneOfMany);
 
-  combo=new Lum::IndexCombo();
-  combo->SetFlex(true,false);
-  combo->SetModel(dest);
-  combo->SetTableModel(destUnits);
-  label->AddLabel(L"Destination Unit:",combo);
+  oneOfMany=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(destDef);
+  oneOfMany->SetFlex(true,false);
+  label->AddLabel(L"Destination Unit:",oneOfMany);
 
   string=new Lum::String();
   string->SetFlex(true,false);
